;; Generated package description from denote-sequence.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-sequence" "0.1.1.0.20250905.174858" "Sequence notes or Folgezettel with Denote" '((emacs "28.1") (denote "4.0.0")) :commit "73838c1ebb26fbc83a488a1b8deecd052c282fea" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-sequence")
